#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 11616 2019-06-07 02:15:46Z Andy $
#
# Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Andy $
# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
# $Revision: 11616 $

from django.conf.urls import url

from Iuppiter.extension.views import getDoc

# If you want add document url to your project, please add a pattern to your
# urls.py by hand.
# Sample:
#   urlpatterns = patterns('',
#       (r'^admin/', include('Theophrastus.document.urls')),
#   )

urlpatterns = [
    # Document.
    url(r'^document/(?P<name>\w+)/$', getDoc, {
        'dir': 'docs',
    }, name='Theophrastus.views.document'),
]
